@@ -9,47 +9,8 @@ from .diff import dff_text
 from .text_tilling import auto_text_tilling
 from .cut import auto_cut_markdown
 import  logging
-def get_markdown_images(text):
-    """
-    从markdown中提取图片
-
-    :param text:
-    :return:
-    """
-    image_arr = re.findall(r'(?:!\[(.*?)\]\((.*?)\))', text)  # 提最述与rul
-    # image_arr = re.findall(r'!\[(.*)\]\((.+)\)', text)  # 提最述与rul
-
-    # print("image_arr", image_arr)
-    return image_arr
-def get_markdown_images_format(text):
-    """
-    对markdown图片进行分割，在图片标签前后添加两个换行
-
-    :param text:
-    :return: []
-    """
-    # image_arr = re.findall(r'(?:!\[(.*?)\]\((.*?)\))', text)  # 提最述与rul
-    for it in re.findall(r'(?:!\[(.*?)\))', text):
-        text=text.replace("!["+it+")","\n\n!["+it+")\n\n")
-    items=[]
-    images_list=[]
-    for it in text.split("\n"):
-        if len(it) >0:
-            it=it.strip().replace(" .",'.').replace(" !",'!').replace(" ;",';').replace(" ?",'?').replace(":.",":")
-            image_arr = re.findall(r'(?:!\[(.*?)\]\((.*?)\))', it)
-            if len(image_arr) > 0:
-                images_list.append(image_arr)
-            else:
-                images_list.append(None)
-
-
-            items.append(it.strip())
-
-
-    # print("image_arr", image_arr)
-    # return "\n".join(items)
-    return items,images_list
 
+from .img import get_markdown_images,get_markdown_images_format
 
 def auto_request(payload, api, timeout=600):
     """
@@ -75,8 +36,10 @@ def auto_request(payload, api, timeout=600):
 
     }
     # response = requests.request("POST", url, json=payload, headers=headers)
-
+    # print(json.dumps(payload))
     response = requests.request("POST", api,data=json.dumps(payload), headers=headers)
+    # print(response.text)
+    # print(response.status_code)
     assert response.status_code==200
     return response.json()
 
@@ -145,7 +108,7 @@ class AutoReWrite(object):
             "max_length": 120,
             "num_return_sequences": 5
             },"text": ["Prized for his intelligence, herding instinct and working ability, the Border Collie was developed more "
-                   "than a century ago in Britain. "]}
+            "than a century ago in Britain. "]}
             out = predict_paraphrase(payload)
             print(out)
 
@@ -242,11 +205,106 @@ class AutoReWrite(object):
                 # "top_k": 50
                 }
         payload={"config":config,
-                 "text": [text]
-                 }
+                "text": [text]
+                }
         return self.predict_summary(payload, timeout=600)
         # pass
 
+
+    def predict_optimize_content(self, payload, timeout=600):
+        """
+        优化内容接口
+        示例：
+
+            payload = {"config": {
+            "num_beams": 5,
+            "max_length": 120,
+            "num_return_sequences": 5
+            },"text": ["Prized for his intelligence, herding instinct and working ability, the Border Collie was developed more "
+                   "than a century ago in Britain. "]}
+            out = predict_summary(payload)
+            print(out)
+
+
+        :param payload:
+        :param api:
+        :param timeout:
+        :return:
+        """
+        api = f"{self.api_host}/predict_optimize_content"
+        return auto_request(payload, api, timeout)
+
+    def auto_optimize_content(self, text,auto_sample=False,temperature=1.15,config=None, **kwargs):
+        """
+        自动优化内容，设置了默认参数
+
+        获取最好的一个摘要信息
+
+
+
+        示例：
+            from tkitAutoRewriter import AutoReWrite, SentenceClassification
+            text = "The Border Collie is a British breed of herding dog of medium size. They are descended from landrace sheepdogs once found all over the British Isles, but became standardized in the Anglo-Scottish border region. Presently they are used primarily as working dogs to herd livestock, specifically sheep.[1] The Border Collie is considered a highly intelligent, extremely energetic, acrobatic and athletic dog. They frequently compete with great success in sheepdog trials and a range of dog sports like dog obedience, disc dog, herding and dog agility. They are one of the most intelligent domestic dog breeds.[2] Border Collies continue to be employed in their traditional work of herding livestock throughout the world and are kept as pets."
+            # rewriter = AutoReWrite(api='http://192.168.1.18:3008')
+            rewriter = AutoReWrite(api='http://127.0.0.1:3000')
+            out = rewriter.auto_summary(text)
+            print(out)
+            > {'results': [[{'summary_text': 'Border Collie: Dog Breed Profile, Characteristics, and Development-Worthy of Homeward-Homeward Herding Dogs of the 21st-century Dog-Ages'}]]}
+
+        :param text:
+        :return:
+        """
+        mi=max(int(len(text.split(" "))*0.6),64)
+        # payload = {"config": {
+        #     "do_sample": auto_sample,
+        #     # "num_beams": 5,
+        #     "max_length": min(mi,128),
+        #     "temperature":temperature
+        #     # "num_return_sequences": 5
+        # }, "text": [text]}
+        # payload = {"config": {
+        #     "do_sample": auto_sample,
+        #     # "num_beams": 5,
+        #     "max_length": min(mi,128),
+        #     "temperature":temperature
+        #     # "num_return_sequences": 5
+        # }, "text": [text]}
+
+        # 自动调参 https://wandb.ai/terrychanorg/uncategorized/sweeps/j64ghxnf?workspace=user-terrychanorg
+        # config={"do_sample": True,
+        #             "max_length": min(mi,128),
+        #             "early_stopping":True,
+        #             "num_return_sequences": 5,
+        #             "no_repeat_ngram_size":5,
+        #             "num_beams":8,
+        #             "temperature":0.7773100411930902,
+        #             "top_p":0.7735368770052764,
+        #             "top_k": 50
+        #             }
+
+        #new1 for cnn
+        if config is None:
+            config={"do_sample": True,
+                "max_length": 1024,
+                "early_stopping":True,
+                "num_return_sequences": 5,
+                # "no_repeat_ngram_size":5,
+                "num_beams":6,
+                # "temperature":0.8532525677925238,
+                # "top_p":0.5793650747162632,
+                # "top_k": 50
+                }
+        payload={"config":config,
+                "text": [f"{text}"]
+                }
+
+        # print(payload)
+        return self.predict_optimize_content(payload, timeout=600)
+
+
+
+
+
     def predict_title(self, payload, timeout=600):
         """
         生成标题
@@ -258,7 +316,7 @@ class AutoReWrite(object):
             "max_length": 64,
             "num_return_sequences": 5
             },"text": ["Prized for his intelligence, herding instinct and working ability, the Border Collie was developed more "
-                   "than a century ago in Britain. "]}
+            "than a century ago in Britain. "]}
             out = predict_paraphrase(payload)
             print(out)
 
